
<template>
    <div>
        <router-view></router-view>
    </div>
</template>

<script>

var http = require('axios');


var components = {
    layout: require('./layout.vue'),
};


var data = {
    ready: false,
    user: null,
    analyses: [],
    metadata: {}
};


function preloadData(user){

    var requests = [
        http.get('api/analyses'),
        http.get('api/metadata')
    ];

    return Promise.all(requests).then(function(responses){
        data.ready = true;
        data.user = user.data;
        data.analyses = Object.freeze(responses[0].data.rows || []);
        data.metadata = Object.freeze(responses[1].data);
    });
}


function unauthorized(err){
    if (err.response && err.response.status == 401){
        data.ready = true;
    }
    else {
        return Promise.reject(err);
    }
}


http.get('api/user').then(preloadData, unauthorized).catch(defaultErrorHandler);


function reloadAnalyses(){
    return http.get('api/analyses').then(function(response){
        data.analyses = Object.freeze(response.data.rows || []);
    });
}


function createAnalysis(params){
    return http.post('api/analyses', params).then(function(response){
        return reloadAnalyses().then(function(){
            return response.data;
        });
    });
}


function deleteAnalysis(id){
    return http.delete('api/analyses/' + id).then(reloadAnalyses).catch(defaultErrorHandler);
}


var methods = {
    createAnalysis: createAnalysis,
    deleteAnalysis: deleteAnalysis
};


module.exports = {
    components: components,
    data: data,
    methods: methods
};


setInterval(reloadAnalyses, 300000); // 5 minutes

</script>